@@ -206,8 +206,8 @@ nautilus_python_init_python (void)
 	if (Py_IsInitialized())
 		return TRUE;
 
-  	debug("g_module_open " PY_LIB_LOC "/libpython" PYTHON_VERSION "." G_MODULE_SUFFIX);
-	libpython = g_module_open(PY_LIB_LOC "/libpython" PYTHON_VERSION "." G_MODULE_SUFFIX, 0);
+  	debug("g_module_open " PY_LIB_LOC "/libpython" PYTHON_VERSION "." G_MODULE_SUFFIX ".1.0");
+	libpython = g_module_open(PY_LIB_LOC "/libpython" PYTHON_VERSION "." G_MODULE_SUFFIX ".1.0", 0);
 	if (!libpython)
 		g_warning("g_module_open libpython failed: %s", g_module_error());
 	debug("Py_Initialize");
@@ -223,6 +223,13 @@ nautilus_python_init_python (void)
 		PyErr_Print();
 		return FALSE;
 	}
+	
+	/* Sanitize sys.path */
+	PyRun_SimpleString("import sys; sys.path = filter(None, sys.path)");
+	if (PyErr_Occurred()) {
+		PyErr_Print();
+		return FALSE;
+	}
 
 	/* pygtk.require("2.0") */
 	debug("pygtk.require(\"2.0\")");
